@@ -49,8 +49,11 @@ def failures(datatype, value, path=''):
             fails.append(_failure(
                 path, 'expected dict, got %s', val_type.__name__))
         else:
+            wildcard = datatype.get('_any_', None)
             all_properties = set()
             for key, subtype in datatype.iteritems():
+                if key == '_any_':
+                    continue
                 key, options = _parse_dict_key(key)
                 all_properties.add(key)
                 subpath = _joinpaths(path, key, '.')
@@ -61,9 +64,16 @@ def failures(datatype, value, path=''):
                         fails.append(_failure(path,
                             'missing required property: "%s"', key
                         ))
-            # check for unexpected properties/keys
-            fails.extend(_failure(path, 'unexpected property "%s"', x)
-                         for x in set(value.keys()) - all_properties)
+
+            if wildcard:
+                # validate wildcard items
+                for key, subvalue in value.iteritems():
+                    subpath = _joinpaths(path, key, '.')
+                    fails.extend(failures(wildcard, subvalue, subpath))
+            else:
+                # check for unexpected properties/keys
+                fails.extend(_failure(path, 'unexpected property "%s"', x)
+                             for x in set(value.keys()) - all_properties)
 
     # List Validation
     elif dt_type == list and len(datatype) == 1:
